@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Tickit::ContainerWidget );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 
@@ -77,6 +77,16 @@ sub add
    $self->SUPER::add( @_ );
 }
 
+sub window_lost
+{
+   my $self = shift;
+
+   my $child = $self->child;
+   $child->set_window( undef ) if $child;
+
+   $self->SUPER::window_lost( @_ );
+}
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
